# Reserved Instances Package

This package allows you to easily calculate the number of instances available based on instane type.
Package also calculates number of reserved instances still available
